@@ -32,14 +32,6 @@ class RelationNotFoundException(Exception):
         self.foreign_model = foreign_model
 
 
-class SqlException(Exception):
-    pass
-
-
-class SqlIntegryException(SqlException):
-    pass
-
-
 class ModelNotFoundException(Exception):
 
     def __init__(self, model, models):
