@@ -111,7 +111,7 @@ class Model(AbstractModel):
         return cls.fields_dict().get(field_name)
 
     @classmethod
-    def get_relation(cls, relation_name):
+    def get_relation(cls, relation_name) -> Relation:
         return cls.relations_dict().get(relation_name)
 
     @classmethod
@@ -252,7 +252,7 @@ class Model(AbstractModel):
     def data(self):
         return self.as_json()
 
-    def get_value(self, attribute):
+    def get_value(self, attribute: str):
         if '.' in attribute:
             related_entity_name, attr = attribute.split('.')
             try:
