@@ -830,8 +830,10 @@ class QueryWizzard:
                     )
         return related_queries
 
-    def get_m21_value(self, relation, filter_column, value):
+    def get_m21_value(self, relation, filter_column, value) -> int or None:
         if relation.load_all:
+            if not value:
+                return None
             return int(value)
         else:
             if filter_column:
